pub enum M2dirEntryParseError {
NotFile(M2dirPath),
MissingFilename(M2dirPath),
InvalidFilename {
path: M2dirPath,
reason: &'static str,
},
InvalidChecksum {
path: M2dirPath,
expected: String,
got: String,
},
}Expand description
Errors that can occur while parsing or validating an entry filename.
Variants
NotFile(M2dirPath)
The given path is not a regular file.
MissingFilename(M2dirPath)
The path has no final filename component.
InvalidFilename
The filename does not match the m2dir specification.
InvalidChecksum
The checksum embedded in the filename does not match the file contents.