pub enum M2dirStoreError {
NotDir(M2dirPath),
NoDotM2store(M2dirPath),
AbsolutePath(String),
EscapesRoot(String),
}Expand description
Errors that can occur while operating on an m2store.
Variants
NotDir(M2dirPath)
The given path is not a directory.
NoDotM2store(M2dirPath)
The given directory does not contain the .m2store marker.
AbsolutePath(String)
The given folder name resolves to an absolute path.
EscapesRoot(String)
The given folder name contains components that fall outside
the m2store root (such as ..).